@@ -51,11 +51,15 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
                                  f"Document contains {id2fact[value.to_fact.id]}, link fact refers to {value.to_fact}")
 
     def _check_mentions_fact(self, facts: Iterable[AbstractFact]):
+        node_cache = {}
         for fact in facts:
             if fact.mention is not None:
                 for men in fact.mention:
                     try:
-                        node = self._content.node(men.node_id)
+                        node = node_cache.get(men.node_id, None)
+                        if node is None:
+                            node = self._content.node(men.node_id)
+                            node_cache[men.node_id] = node
                     except ValueError:
                         raise ValueError(f"Mention {men} facts {fact} does not apply to this document")
                     if men.end_idx > len(node.node_text):
