@@ -1,12 +1,22 @@
 from abc import abstractmethod
-from typing import Any, Callable, Dict, Optional, Tuple
+from typing import Any, Callable, Dict, Optional, Tuple, Union
 
 from pydantic import BaseModel
 
 from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, AbstractTreeDocumentContent, FactStatus, FactType
 from tdm.abstract.datamodel.fact import AbstractLinkValue, FactMetadata
+from tdm.abstract.json_schema import MetadataModel
 from tdm.datamodel import TalismanSpan
-from tdm.json_schema.metadata import FactMetadataModel
+
+
+class FactMetadataModel(MetadataModel):
+    created_time: Optional[int]
+    modified_time: Optional[int]
+    fact_confidence: Optional[Tuple[float]]
+    value_confidence: Union[float, Tuple[float, ...], None]  # same as Optional[float, Tuple[float, ...]] (pydantic bug workaround)
+
+    class Config:
+        extra = 'allow'  # any other extra fields will be kept
 
 
 class SpanModel(BaseModel):
